#
# spec file for package lout
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lout
Version:        3.42.2
Release:        bp156.2.49
Summary:        A document formatting system
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/PS
URL:            https://savannah.nongnu.org/projects/lout/
Source0:        https://github.com/william8000/lout/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  ghostscript

%description
Lout is a document formatting system. The system reads a high-level
description of a document similar in style to LaTeX and produces a
PostScript file. Plain text output is also available, PDF output is
limited but working (e.g. no graphics). Either of these may be
fed to a printer. Lout is offered in multiple languages.

%prep
%setup -q
find . -name README -exec chmod 0644 '{}' \;

%build
make COPTS="%{optflags}" \
     BINDIR=%{_bindir} \
     LOUTLIBDIR=%{_datadir}/%{name} \
     LOUTDOCDIR=%{_datadir}/%{name}/doc \
     MANDIR=%{_mandir}/man1 \
     prg2lout lout

function render_docs {
    subdir=$1
    pdf_file=$2
    passes=$3

    curdir=$(pwd)
    pushd doc/$subdir

    # We need to set the PATH variable here, because lout eventually exec's
    #   prg2lout.  In order for lout to find the latter, we have to set the
    #   PATH.
    # We also need to tell lout where to find its files, since we haven't
    #   installed them in their final location under %%{_datadir}/lout/ yet.
    PATH=$curdir lout \
       -I $curdir/include \
       -D $curdir/data \
       -F $curdir/font \
       -H $curdir/hyph \
       -C $curdir/maps \
       -r${passes} all > outfile.ps
    # Note that the above clobbers the prebuilt file outfile.ps that is
    # included in Lout's source tarball.
    ps2pdf outfile.ps ../${pdf_file}
    rm *.li *.ld outfile.ps
    popd
}

render_docs design design.pdf       3
render_docs expert expert-guide.pdf 4
render_docs slides slides.pdf       2
render_docs user   user-guide.pdf   6

%install
mkdir -p %{buildroot}%{_bindir}
make BINDIR=%{buildroot}%{_bindir} \
     LOUTLIBDIR=%{buildroot}%{_datadir}/%{name} \
     LOUTDOCDIR=%{buildroot}%{_datadir}/%{name}/doc \
     MANDIR=%{buildroot}%{_mandir}/man1 \
     install installman installdoc
%fdupes %{buildroot}%{_datadir}/%{name}

%files
%doc README READMEPDF
%license COPYING
%{_bindir}/*
%{_datadir}/%{name}/
%{_mandir}/man1/*.1%{?ext_man}

%changelog
* Tue Nov 22 2022 Dirk Müller <dmueller@suse.com>
- update to 3.42.2:
  * blf : fix typo in @paintbox PDF backend
  * include/lengths: Remove undefined __loutd reference.
* Tue Mar 22 2022 Matej Cepl <mcepl@suse.com>
- Update to 3.42.1:
  - Update README version.
  - Include README in updateversion.sh
  - Ensure BINDIR is created
  - makefile: Only chmod BINDIR if it is freshly created.
  - Ensure CFLAGS/LDFLAGS can be passed to compiler
* Fri May 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Use fork by William Bader
  * https://mail.gnu.org/archive/html/lout-users/2021-04/msg00001.html
- Update to version 3.42:
  * Support for embedding PDF and bitmapped images in lout.
  * Small images are now placed more accurately.
  * Improve accuracy of the CM unit.
  * Add support for segmented postscript files.
  * Fix the fatal error "AdjustSize: Up(x) == x!"
  * Fix possible memory overwrite
  * Fix some bad memory accesses
  * Full changes:
    https://github.com/william8000/lout/blob/3.42/whatsnew#L615
- Update to version 3.41:
  * Fix CVE-2019-19918 and CVE-2019-19917
- Always generate the PDFs, dropped as sources
- Drop upstream resolved
  * makefile.patch
  * lout-3.40-cve.patch
* Fri Oct 23 2020 Matej Cepl <mcepl@suse.com>
- Add lout-3.40-cve.patch from
  https://lists.nongnu.org/archive/html/lout-users/2020-10/msg00013.html
  fixing  bsc#1159713 and bsc#1159714 (CVE-2019-19918 and
  CVE-2019-19917), two buffer overflows.
* Tue Sep  3 2019 Matej Cepl <mcepl@suse.com>
- Why in the world we set executable bit on README? Fixed.
* Mon Nov 12 2018 Jan Engelhardt <jengelh@inai.de>
- Trim authorship info that does not belong into the description.
  Move printer mention to cover all cases. Trim bias.
* Sun Jul  1 2018 mcepl@suse.com
- Clean up SPEC file to eliminate warnings.
* Sun Nov  5 2017 o.g.m.belleux@gmail.com
- openSUSE initial release
-- initial build for opensuse leap 42.2 & 42.3
-- initial build for opensuse tumbleweed
